# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_file.models.file_file_repository_response import FileFileRepositoryResponse

class TestFileFileRepositoryResponse(unittest.TestCase):
    """FileFileRepositoryResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileFileRepositoryResponse:
        """Test FileFileRepositoryResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FileFileRepositoryResponse`
        """
        model = FileFileRepositoryResponse()
        if include_optional:
            return FileFileRepositoryResponse(
                pulp_href = '',
                prn = '',
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                versions_href = '',
                pulp_labels = {
                    'key' : ''
                    },
                latest_version_href = '',
                name = '',
                description = '',
                retain_repo_versions = 1,
                remote = '',
                autopublish = True,
                manifest = 'PULP_MANIFEST'
            )
        else:
            return FileFileRepositoryResponse(
                name = '',
        )
        """

    def testFileFileRepositoryResponse(self):
        """Test FileFileRepositoryResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
